@@ -17,8 +17,11 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Iterable, Sequence
 
+from deprecated import deprecated
+
 from airflow.exceptions import AirflowException
 from airflow.providers.amazon.aws.hooks.dms import DmsHook
 from airflow.sensors.base import BaseSensorOperator
@@ -41,13 +44,13 @@ class DmsTaskBaseSensor(BaseSensorOperator):
         the task reaches any of these states
     """
 
-    template_fields: Sequence[str] = ('replication_task_arn',)
+    template_fields: Sequence[str] = ("replication_task_arn",)
     template_ext: Sequence[str] = ()
 
     def __init__(
         self,
         replication_task_arn: str,
-        aws_conn_id='aws_default',
+        aws_conn_id="aws_default",
         target_statuses: Iterable[str] | None = None,
         termination_statuses: Iterable[str] | None = None,
         *args,
@@ -58,31 +61,31 @@ class DmsTaskBaseSensor(BaseSensorOperator):
         self.replication_task_arn = replication_task_arn
         self.target_statuses: Iterable[str] = target_statuses or []
         self.termination_statuses: Iterable[str] = termination_statuses or []
-        self.hook: DmsHook | None = None
 
+    @deprecated(reason="use `hook` property instead.")
     def get_hook(self) -> DmsHook:
-        """Get DmsHook"""
-        if self.hook:
-            return self.hook
-
-        self.hook = DmsHook(self.aws_conn_id)
+        """Get DmsHook."""
         return self.hook
 
+    @cached_property
+    def hook(self) -> DmsHook:
+        return DmsHook(self.aws_conn_id)
+
     def poke(self, context: Context):
-        status: str | None = self.get_hook().get_task_status(self.replication_task_arn)
+        status: str | None = self.hook.get_task_status(self.replication_task_arn)
 
         if not status:
             raise AirflowException(
-                f'Failed to read task status, task with ARN {self.replication_task_arn} not found'
+                f"Failed to read task status, task with ARN {self.replication_task_arn} not found"
             )
 
-        self.log.info('DMS Replication task (%s) has status: %s', self.replication_task_arn, status)
+        self.log.info("DMS Replication task (%s) has status: %s", self.replication_task_arn, status)
 
         if status in self.target_statuses:
             return True
 
         if status in self.termination_statuses:
-            raise AirflowException(f'Unexpected status: {status}')
+            raise AirflowException(f"Unexpected status: {status}")
 
         return False
 
@@ -98,19 +101,19 @@ class DmsTaskCompletedSensor(DmsTaskBaseSensor):
     :param replication_task_arn: AWS DMS replication task ARN
     """
 
-    template_fields: Sequence[str] = ('replication_task_arn',)
+    template_fields: Sequence[str] = ("replication_task_arn",)
     template_ext: Sequence[str] = ()
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.target_statuses = ['stopped']
+        self.target_statuses = ["stopped"]
         self.termination_statuses = [
-            'creating',
-            'deleting',
-            'failed',
-            'failed-move',
-            'modifying',
-            'moving',
-            'ready',
-            'testing',
+            "creating",
+            "deleting",
+            "failed",
+            "failed-move",
+            "modifying",
+            "moving",
+            "ready",
+            "testing",
         ]
